/* Generated by wayland-scanner 1.23.1 */

#ifndef XWAYLAND_KEYBOARD_GRAB_UNSTABLE_V1_ENUM_PROTOCOL_H
#define XWAYLAND_KEYBOARD_GRAB_UNSTABLE_V1_ENUM_PROTOCOL_H

#ifdef  __cplusplus
extern "C" {
#endif

#ifdef  __cplusplus
}
#endif

#endif
